Authors
=======

This file contains the list of people involved in the development
of pytest-dynamodb along its history.

* Tomasz Święcicki
* Karolina Blumke
* Grzegorz Śliwiński
* Łukasz Kostka
* Damian Skrzypczak